Index: build/gypi_to_gn.py |
diff --git a/build/gypi_to_gn.py b/build/gypi_to_gn.py |
index a107f94fcafd14c9883c57f4438f064fd8ded1e8..6de1a6385df9d8c4d4d1b5b59ce652f0d93463d6 100644 |
--- a/build/gypi_to_gn.py |
+++ b/build/gypi_to_gn.py |
@@ -96,10 +96,12 @@ def LoadPythonDictionary(path): |
if 'target_conditions' in file_data: |
del file_data['target_conditions'] |
# Strip targets in the toplevel, since some files define these and we can't |
# slurp them in. |
if 'targets' in file_data: |
del file_data['targets'] |
+ if 'includes' in file_data: |
+ del file_data['includes'] |
return file_data |
@@ -96,10 +96,12 @@ def LoadPythonDictionary(path): |
if 'target_conditions' in file_data: |
del file_data['target_conditions'] |
- # Strip targets in the toplevel, since some files define these and we can't |
- # slurp them in. |
+ # Strip targets and includes in the toplevel, since some files define these |
+ # and we can't slurp them in. |
if 'targets' in file_data: |
del file_data['targets'] |